==> ZenTaoPMS.pro8.9.4.php7.0.zip: zentaopms/lib/spout/Common/Exception/EncodingConversionException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPxY3rLm/QIwJSZH0Vs2BJsnbnpbPDtF1njmefM20uL5rIIsni4jtaR/S46Qzsneu+puT8u66
xVo8Izev1/PPWlb0cyoZ5gsfKefKpJVS8wg3sa49MwZM3uZhLqhtMnnFTT/gGi8Su2H4ejTvedNB
AmEV6rQXl2CGZhHIJDofwvgX70a8Ye7v5rrMC+fKmlIjNZPxrW3wE9WLVXyFmsfZJSD3S0y2xmc2
GFziLpuve+ulv+kNOGmUKsyzLk8h/VFZ2iQX+cFyzdwG3rCPM9OzZKyA81rFuZV0ScqpPCrnIzaf
aJYUaObArei/GWrlduirfJRbeToDKgVzx5BmgDcw4McaoiGUc9AIrnXEQ7PRMyA0prboo9P1EuK1
I1AOX58QWdimFnaA1WVx5upKZMZG3Ebur7U20no12ZFnXjy6oaPhRc/ThQ7ObFgiP7HDMcetGAf+
6psay6bVNMufsf25Atdo3oEUBizHallnNmB0SJNf7AS6uJOuk0QOrn1ZoZwX+5OucVBdACHhauWW
L8WsULWJXRwRtRtMLvpzhtwzqE3CzXRKCBTJ7D+nyYplrg1GnPDLXicZHbssDxb6rXe2Y0Oh7/J9
XDVzrzFqXdzEbFrN2jBVKe4fI/3W5d5pMy5zccoUqGid+TyjkO32ikQ702VfqCgWozK/A0afCm0s
ngh4KtCUI+o2ljLBB0xEiIV4kO2W/4Fp9uI7uLge31Zw16eZzrxsruXtL23VM9FhMWqQpK7MP7W4
usib4uu1Cl+GQEQ7PewBRumLpomv3rVdGDOpXuzR8gJ73l412mwZcHavVdoYRAd10iaojksuye+O
WPgB59FnwKn8MdxEUpQ0pmyXhSeS05DbgEb1bikCpDAg3nr2rDk+RnPGipTZwCH6ANlWZ0jp7uNI
EWy2WJtp1n2Oj1LrZpd+Igbub7neFaFFmaOqaa/FXwmUP8KDLLtosLRfz3+TCsC7RcSU0ybDaQ2b
GmsYW2Edy9jpQ1C+g3HThiNfgcBR+1jRGvz2c+q58z+IwuBMJ6Beh3PQVC2w7WTX57MJA0RUlnso
CdbXrhtFx3Fxpv0WcaXyhUwSHqqMffT/E1db1Tc4zUdufh46/zEU/EHOE9zXrgRMwHEDJ9J6xqTc
xDZ/v64THAZ7W4y+WRD7qHJ8Z+5rQF4XMZivTB6M+mMWGa4KS8EtuJUWHO2Irxd2KpLgFbVz4edF
GfJ/qU6FT7dQ9vD+S984P/JBUs9W4ZMtk+VdOGy4FMeKqh3unHz/eVyYuuFWjiYoDyq9kAVXbKXr
nyGWq2l8blYVXQ6rm5DyW3wZr+9yP9F2EXeetQp78WhaNEOgTpASjUclJ6Jtgbv26uUd7efPDXfu
lKH2qmjZXMvxNx5oG+eNTjr7kGpZqze0lf1mohXhBnd8W+3xlJqtgeNxoCoDZpi89hhwUt78APHW
iaBrXVMLia8fuMSPEG+CL0xxZAj6gxOkTiI7d9BLRGnjOm4TOl7yz8AMEuquYxvlW8whgvvfgG==

==> ZenTaoPMS.pro10.0.rc1.php7.1.zip: zentaopms/lib/spout/Common/Exception/EncodingConversionException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPtQZw5Q+Yj6PynPzTU9WgePitc6lkI00S/CiembOjS39szcMnOIcP0721Daxl62jO8kNfPMt
AKEeeucGePeIKPm87NV3O5/cbMEDfH4ErCNxVwwipYKMYvMHy8WREU4UI/GlbftLrDc63XwyG9Ru
a6OLjXHIYzfb5gQ4EFDOsug2gbuOqSAVEQ+csInqqpf5xPisHmbwWhvi5oPIsH72WUzYqTFptNz0
G+FHHZXnVt/lYNIgwpg4B67MrqyarAepWVLvr2N55+ZfBfKizHr3EWz+eaf0PExIRUOsbTb1fqbN
G06PR2Hk6CrH7jOggc81JTWCF/4It36qERQdLEfbkqF+V39zhsomHp/kYpX84NurtQqh9oCMx/+S
9j5Uxv9kn+iZET8m6DMEtPJIR3OzoYqb2DVWxbT81LJ/KhlarB06AwwlMSbZ2O6RaqjzWSD7P0c6
PMCh4YnmJb6W/CdCXas1DY3B2GpPoX6t6/IXJ0VfnVn0O+vYZfi4yfK8xbneMZsYE2ZAEbxJkp+h
7fqq7Khg0SIaJdfTSnolsGk4yu5FGWuKEeYZXRRhiHMS6hx/yopk7iq9RpRSaVSLR36vlhRDCBYR
/WNbGMAg8r/N7f/qty9zzBnNd+HibTKSJYzz/TvAab5ig3O1lyR68bc2NAC3LzBqeLfJx+6c1k4r
+C+lwcH9NXbWW7+shj5PHn3xN0CzEvux36kQDKSYt16FxjS9fn5JGSGwicK1hgk1AKA+RriVCw0U
l3eb2paUQvVMY478QVPZSZaLlumsacRnk8cuB0IZHqFJTttdGubjUHouMTzV7cEgpcaUea0SzF2O
h7Tl+kcBvMuuNwcCO/of8vkODcObKkK337sE2/OJfCRgJ3G6CmWsXqSHUxRo4+qSY1Lve1YbU1FC
6x634ApWRiQ+KhEWk0==
